@@ -419,3 +419,10 @@ class APIClient(object):
         rjson = response.json()
         if response.text != '{}':
             raise SlideScoreErrorException("Failed updating slide description: " + response.text);
+    
+    def update_slide_name(self, image_id, new_name):
+        response = self.perform_request("UpdateSlideName", {"imageId": image_id, "newName": new_name}, method="POST")
+        rjson = response.json()
+        if response.text != '{}':
+            raise SlideScoreErrorException("Failed updating slide name: " + response.text);
+
